==> jc-1.4.0.tar.gz: polyglot/lex/BooleanLiteral.h <==
// public class polyglot.lex.BooleanLiteral

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c615f7824828096c polyglot_lex_BooleanLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_BooleanLiteral_H_
#define _JC_polyglot_lex_BooleanLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_BooleanLiteral$sub_refs	_jc_polyglot_lex_BooleanLiteral$sub_refs;
typedef struct _jc_polyglot_lex_BooleanLiteral$sub_nonrefs	_jc_polyglot_lex_BooleanLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_BooleanLiteral$refs	_jc_polyglot_lex_BooleanLiteral$refs;
typedef struct _jc_polyglot_lex_BooleanLiteral$nonrefs	_jc_polyglot_lex_BooleanLiteral$nonrefs;
typedef struct _jc_polyglot_lex_BooleanLiteral$object	_jc_polyglot_lex_BooleanLiteral$object;

typedef const struct _jc_polyglot_lex_BooleanLiteral$vmethods	_jc_polyglot_lex_BooleanLiteral$vmethods;
typedef const struct _jc_polyglot_lex_BooleanLiteral$vtable	_jc_polyglot_lex_BooleanLiteral$vtable;
typedef const struct _jc_polyglot_lex_BooleanLiteral$vtype	_jc_polyglot_lex_BooleanLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_BooleanLiteral$method$_init$1b8ec325269c7763(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *, struct _jc_polyglot_util_Position$object *, jboolean, jint);

// Virtual methods
extern struct _jc_java_lang_Boolean$object *_jc_polyglot_lex_BooleanLiteral$method$getValue$8d457ef2dfb4d072(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *);
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_BooleanLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_BooleanLiteral$method_info$getValue$8d457ef2dfb4d072;
extern _jc_method _jc_polyglot_lex_BooleanLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_BooleanLiteral$vmethods {
	struct _jc_java_lang_Boolean$object	*(*getValue$8d457ef2dfb4d072)(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *);
};

// Vtable
struct _jc_polyglot_lex_BooleanLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_BooleanLiteral$vmethods	polyglot_lex_BooleanLiteral;
};

// Vtype
struct _jc_polyglot_lex_BooleanLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_BooleanLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_BooleanLiteral$sub_refs {
	struct _jc_java_lang_Boolean$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_BooleanLiteral$refs {
    _jc_polyglot_lex_BooleanLiteral$sub_refs	polyglot_lex_BooleanLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_BooleanLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_BooleanLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_BooleanLiteral$sub_nonrefs	polyglot_lex_BooleanLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_BooleanLiteral$object {
	_jc_polyglot_lex_BooleanLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_BooleanLiteral$vtype	*vtype;
	_jc_polyglot_lex_BooleanLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_BooleanLiteral$vtype _jc_polyglot_lex_BooleanLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_BooleanLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_BooleanLiteral$class_object;

#endif	/* _JC_polyglot_lex_BooleanLiteral_H_ */

==> jc-1.4.6.tar.gz: polyglot/lex/BooleanLiteral.h <==
// public class polyglot.lex.BooleanLiteral

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c615f7824828096c polyglot_lex_BooleanLiteral
// @dep_class 923d72acc1d3eef7 polyglot_lex_Literal
// @dep_class 28b2d50426072b60 polyglot_lex_Token

// header file dependencies
// @dep_header polyglot_lex_Literal

#include "polyglot/lex/Literal.h"

#ifndef _JC_polyglot_lex_BooleanLiteral_H_
#define _JC_polyglot_lex_BooleanLiteral_H_

// Forward structure declarations
struct _jc_java_lang_Boolean$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_util_Position$object;

// Typedefs
typedef struct _jc_polyglot_lex_BooleanLiteral$sub_refs	_jc_polyglot_lex_BooleanLiteral$sub_refs;
typedef struct _jc_polyglot_lex_BooleanLiteral$sub_nonrefs	_jc_polyglot_lex_BooleanLiteral$sub_nonrefs;
typedef struct _jc_polyglot_lex_BooleanLiteral$refs	_jc_polyglot_lex_BooleanLiteral$refs;
typedef struct _jc_polyglot_lex_BooleanLiteral$nonrefs	_jc_polyglot_lex_BooleanLiteral$nonrefs;
typedef struct _jc_polyglot_lex_BooleanLiteral$object	_jc_polyglot_lex_BooleanLiteral$object;

typedef const struct _jc_polyglot_lex_BooleanLiteral$vmethods	_jc_polyglot_lex_BooleanLiteral$vmethods;
typedef const struct _jc_polyglot_lex_BooleanLiteral$vtable	_jc_polyglot_lex_BooleanLiteral$vtable;
typedef const struct _jc_polyglot_lex_BooleanLiteral$vtype	_jc_polyglot_lex_BooleanLiteral$vtype;

// Constructors
extern void _jc_polyglot_lex_BooleanLiteral$method$_init$1b8ec325269c7763(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *, struct _jc_polyglot_util_Position$object *, jboolean, jint) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Boolean$object *_jc_polyglot_lex_BooleanLiteral$method$getValue$8d457ef2dfb4d072(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_polyglot_lex_BooleanLiteral$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_lex_BooleanLiteral$method_info$getValue$8d457ef2dfb4d072;
extern _jc_method _jc_polyglot_lex_BooleanLiteral$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_polyglot_lex_BooleanLiteral$vmethods {
	struct _jc_java_lang_Boolean$object	*(*getValue$8d457ef2dfb4d072)(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_polyglot_lex_BooleanLiteral$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_lex_BooleanLiteral$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_lex_Token$vmethods	polyglot_lex_Token;
	_jc_polyglot_lex_Literal$vmethods	polyglot_lex_Literal;
	_jc_polyglot_lex_BooleanLiteral$vmethods	polyglot_lex_BooleanLiteral;
};

// Vtype
struct _jc_polyglot_lex_BooleanLiteral$vtype {
	_jc_type			type;
	_jc_polyglot_lex_BooleanLiteral$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_lex_BooleanLiteral$sub_refs {
	struct _jc_java_lang_Boolean$object	*val;
};

// Reference instance fields (object)
struct _jc_polyglot_lex_BooleanLiteral$refs {
    _jc_polyglot_lex_BooleanLiteral$sub_refs	polyglot_lex_BooleanLiteral;
    _jc_polyglot_lex_Literal$sub_refs	polyglot_lex_Literal;
    _jc_polyglot_lex_Token$sub_refs	polyglot_lex_Token;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_lex_BooleanLiteral$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_lex_BooleanLiteral$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_lex_Token$sub_nonrefs	polyglot_lex_Token;
    _jc_polyglot_lex_Literal$sub_nonrefs	polyglot_lex_Literal;
    _jc_polyglot_lex_BooleanLiteral$sub_nonrefs	polyglot_lex_BooleanLiteral;
};

// Object instance structure
struct _jc_polyglot_lex_BooleanLiteral$object {
	_jc_polyglot_lex_BooleanLiteral$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_lex_BooleanLiteral$vtype	*vtype;
	_jc_polyglot_lex_BooleanLiteral$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_lex_BooleanLiteral$vtype _jc_polyglot_lex_BooleanLiteral$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_lex_BooleanLiteral, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_lex_BooleanLiteral$class_object;

#endif	/* _JC_polyglot_lex_BooleanLiteral_H_ */
